==> glue-1.93.0-sources.jar: software/amazon/awscdk/services/glue/Type.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) Represents a type of a column in a table schema.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.489Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.Type")
@software.amazon.jsii.Jsii.Proxy(Type.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface Type extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Glue InputString for this type.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getInputString();

    /**
     * (experimental) Indicates whether this type is a primitive data type.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.Boolean getIsPrimitive();

    /**
     * @return a {@link Builder} of {@link Type}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Type}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<Type> {
        private java.lang.String inputString;
        private java.lang.Boolean isPrimitive;

        /**
         * Sets the value of {@link Type#getInputString}
         * @param inputString Glue InputString for this type. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder inputString(java.lang.String inputString) {
            this.inputString = inputString;
            return this;
        }

        /**
         * Sets the value of {@link Type#getIsPrimitive}
         * @param isPrimitive Indicates whether this type is a primitive data type. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder isPrimitive(java.lang.Boolean isPrimitive) {
            this.isPrimitive = isPrimitive;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Type}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public Type build() {
            return new Jsii$Proxy(inputString, isPrimitive);
        }
    }

    /**
     * An implementation for {@link Type}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Type {
        private final java.lang.String inputString;
        private final java.lang.Boolean isPrimitive;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.inputString = software.amazon.jsii.Kernel.get(this, "inputString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.isPrimitive = software.amazon.jsii.Kernel.get(this, "isPrimitive", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String inputString, final java.lang.Boolean isPrimitive) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.inputString = java.util.Objects.requireNonNull(inputString, "inputString is required");
            this.isPrimitive = java.util.Objects.requireNonNull(isPrimitive, "isPrimitive is required");
        }

        @Override
        public final java.lang.String getInputString() {
            return this.inputString;
        }

        @Override
        public final java.lang.Boolean getIsPrimitive() {
            return this.isPrimitive;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("inputString", om.valueToTree(this.getInputString()));
            data.set("isPrimitive", om.valueToTree(this.getIsPrimitive()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-glue.Type"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Type.Jsii$Proxy that = (Type.Jsii$Proxy) o;

            if (!inputString.equals(that.inputString)) return false;
            return this.isPrimitive.equals(that.isPrimitive);
        }

        @Override
        public final int hashCode() {
            int result = this.inputString.hashCode();
            result = 31 * result + (this.isPrimitive.hashCode());
            return result;
        }
    }
}

==> glue-1.182.0-sources.jar: software/amazon/awscdk/services/glue/Type.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) Represents a type of a column in a table schema.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Database myDatabase;
 * Table.Builder.create(this, "MyTable")
 *         .database(myDatabase)
 *         .tableName("my_table")
 *         .columns(List.of(Column.builder()
 *                 .name("col1")
 *                 .type(Schema.STRING)
 *                 .build()))
 *         .partitionKeys(List.of(Column.builder()
 *                 .name("year")
 *                 .type(Schema.SMALL_INT)
 *                 .build(), Column.builder()
 *                 .name("month")
 *                 .type(Schema.SMALL_INT)
 *                 .build()))
 *         .dataFormat(DataFormat.JSON)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:43.505Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.Type")
@software.amazon.jsii.Jsii.Proxy(Type.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface Type extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Glue InputString for this type.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getInputString();

    /**
     * (experimental) Indicates whether this type is a primitive data type.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.Boolean getIsPrimitive();

    /**
     * @return a {@link Builder} of {@link Type}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Type}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<Type> {
        java.lang.String inputString;
        java.lang.Boolean isPrimitive;

        /**
         * Sets the value of {@link Type#getInputString}
         * @param inputString Glue InputString for this type. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder inputString(java.lang.String inputString) {
            this.inputString = inputString;
            return this;
        }

        /**
         * Sets the value of {@link Type#getIsPrimitive}
         * @param isPrimitive Indicates whether this type is a primitive data type. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder isPrimitive(java.lang.Boolean isPrimitive) {
            this.isPrimitive = isPrimitive;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Type}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public Type build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Type}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Type {
        private final java.lang.String inputString;
        private final java.lang.Boolean isPrimitive;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.inputString = software.amazon.jsii.Kernel.get(this, "inputString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.isPrimitive = software.amazon.jsii.Kernel.get(this, "isPrimitive", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.inputString = java.util.Objects.requireNonNull(builder.inputString, "inputString is required");
            this.isPrimitive = java.util.Objects.requireNonNull(builder.isPrimitive, "isPrimitive is required");
        }

        @Override
        public final java.lang.String getInputString() {
            return this.inputString;
        }

        @Override
        public final java.lang.Boolean getIsPrimitive() {
            return this.isPrimitive;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("inputString", om.valueToTree(this.getInputString()));
            data.set("isPrimitive", om.valueToTree(this.getIsPrimitive()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-glue.Type"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Type.Jsii$Proxy that = (Type.Jsii$Proxy) o;

            if (!inputString.equals(that.inputString)) return false;
            return this.isPrimitive.equals(that.isPrimitive);
        }

        @Override
        public final int hashCode() {
            int result = this.inputString.hashCode();
            result = 31 * result + (this.isPrimitive.hashCode());
            return result;
        }
    }
}
